from itertools import islice
from zope.interface import implements

from pyramid.renderers import render
from pyramid.security import effective_principals

from karl.utils import find_events
from karl.views.interfaces import IIntranetPortlet
from karl.content.views.adapters import AbstractPortlet
from karl.views.contentfeeds import _update_feed_items


class LatestActivityPortlet(AbstractPortlet):
    """ use the content feeds to show the 5 most recently added items
    """
    implements(IIntranetPortlet)

    @property
    def title(self):
        return "Latest Activity"

    @property
    def entries(self):
        """ return 5 of the latest content feed items
        """
        principals = effective_principals(self.request)
        created_by = None
        latest = []
        events = find_events(self.context)
        site_events = events.checked(principals, created_by)

        while len(latest) < 5:
            try:
                event = site_events.next()
                if event[2]['operation'] in ['tagged', 'joined'] or \
                   event[2]['content_type'] in ['Person', 'Wiki', 'Wiki Page']:
                    continue
                latest.append(event)
            except StopIteration:
                break

        feed_items = _update_feed_items(latest, self.request.application_url)
        return feed_items

    @property
    def asHTML(self):
        """ render our portlet
        """
        return render(
            'templates/latestactivity.pt',
            {'title': self.title,
             'latest_items': self.entries},
            request=self.request
            )
